from flask_restful import Resource, reqparse
from common.interceptors import auth_required_time
from flask import jsonify,request
from common import redis_helper,utils
from wechat import gewe_chat


class SendSNSTextResource(Resource):

    def __init__(self):
        self.parser = reqparse.RequestParser()
        self.wxchat = gewe_chat.wxchat

    @auth_required_time
    def post(self):
        req = request.get_json()
        content = req.get("content")

        ret, msg, data = self.wxchat.send_text_sns(request.environ['token_id'], request.environ['app_id'], content)

        if ret != 200:
            response = jsonify({
                'code': ret,
                'message': msg
            })
            response.status_code = ret
            response.message = msg
            return  response
        return jsonify(data)


class SendSNSImageResource(Resource):
    
    def __init__(self):
        self.parser = reqparse.RequestParser()
        self.wxchat = gewe_chat.wxchat

    @auth_required_time
    def post(self):
        req = request.get_json()
        content = req.get("content","")
        image_urls=req.get("imageUrls",[])    
        ret, msg, data = self.wxchat.upload_sns_image(request.environ['token_id'], request.environ['app_id'], image_urls)
        if ret != 200:
            response = jsonify({
                'code': ret,
                'message': msg
            })
            response.status_code = ret
            response.message = msg
            return  response
        

        ret, msg, data = self.wxchat.send_image_sns(request.environ['token_id'], request.environ['app_id'], content,data)
        if ret != 200:
            response = jsonify({
                'code': ret,
                'message': msg
            })
            response.status_code = ret
            response.message = msg
            return  response
        return jsonify(data)
    

class SendSNSVideoResource(Resource):
    
    def __init__(self):
        self.parser = reqparse.RequestParser()
        self.wxchat = gewe_chat.wxchat

    @auth_required_time
    def post(self):
        req = request.get_json()
        content = req.get("content","")
        video_url=req.get("videoUrl","")
        video_thumb_url=req.get("videoThumbUrl","")
        ret, msg, data = self.wxchat.upload_sns_video(request.environ['token_id'], request.environ['app_id'], video_url,video_thumb_url)
        if ret != 200:
            response = jsonify({
                'code': ret,
                'message': msg
            })
            response.status_code = ret
            response.message = msg
            return  response
        

        ret, msg, data = self.wxchat.send_video_sns(request.environ['token_id'], request.environ['app_id'], content,data)
        if ret != 200:
            response = jsonify({
                'code': ret,
                'message': msg
            })
            response.status_code = ret
            response.message = msg
            return  response
        return jsonify(data)